/*
 * Copyright (C) 2017 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef GAPIR_RESOURCE_CACHE_H
#define GAPIR_RESOURCE_CACHE_H

#include "replay_service.h"
#include "resource.h"
#include "resource_loader.h"

#include <memory>
#include <vector>

namespace gapir {

// ResourceCache is an abstract base class for caching resources.
class ResourceCache {
 public:
  virtual ~ResourceCache() {}

  // putCache caches the given resource and its data. Returns true if caching
  // is done successfully, otherwise false.
  virtual bool putCache(const Resource& res, const void* resData) = 0;
  // hasCache returns true if the given resource has been cached, otherwise
  // false.
  virtual bool hasCache(const Resource& res) = 0;
  // loadCache loads the resource data to the given target location. Returns
  // true if loading is done successfully, otherwise false and do not load
  // anything to the target location.
  virtual bool loadCache(const Resource& res, void* target) = 0;
  // size returns the total size in bytes that can be used for caching.
  virtual size_t totalCacheSize() const = 0;
  // resize adjust the total size in bytes that can be used for this cache.
  virtual bool resize(size_t newSize) = 0;
  // prefetch get the resources data through the given loader, and put as much
  // as possble resource data in cache. Returns the number of resources put in
  // cache.
  virtual size_t prefetch(const Resource* res, size_t count,
                          ResourceLoader* fetcher);
  // debug print the internal state.
  virtual void dump(FILE*) {}
};

}  // namespace gapir

#endif  // GAPIR_RESOURCE_CACHE_H
